#!/bin/bash

# Get command line parameters
if [ "$#" -ne 3 ]; then
    echo "Error: illegal number of arguments: "$#
    echo "Usage: install.sh INFLUX_URL DATABASE_NAME REPORT_PERIOD"
    exit 1 
fi

INFLUX_URL=$1
DATABASE_NAME=$2
REPORT_PERIOD=$3

## CLMC-SERVICE
## ----------------------------------------------------------------------------------
echo "----> Configuring virtualenvwrapper"
export WORKON_HOME=$HOME/.virtualenvs
source /usr/local/bin/virtualenvwrapper.sh

# check the mkvirtualenv with a return value of 1 if version comes back correctly
mkvirtualenv --version
if [ $? -ne 1 ] ; then
        echo "Failed: installing virtualenvwrapper"
		exit 1
fi

# create CLMC virtual environment - and check
echo "----> Making CLMC Python environment"
mkvirtualenv CLMC
if [ $? -ne 0 ] ; then
        echo "Failed: creating CLMC python environment"
		exit 1
fi

# switch the CLMC environment - and check
echo "----> Switching to use CLMC python environment"
workon CLMC
if [ $? -ne 0 ] ; then
        echo "Failed: switching to CLMC python environment"
		exit 1
fi

# install tox - and check
echo "----> Installing TOX"
pip3 install tox
tox --version
if [ $? -ne 0 ] ; then
        echo "Failed: installing tox"
		exit 1
fi

# navigate to the clmc-webservice - and check
echo "----> Moving to CLMC webservice"
cd ${REPO_ROOT}/src/service
if [ $? -ne 0 ] ; then
        echo "Failed: could not find clmc-webservice"
		exit 1
fi

# running tests using tox
echo "----> Running tox"
TOX_OUTPUT="$(tox)"
# check if tox output contains the 'congratulations :)' bit for tests passed
if [[ $TOX_OUTPUT != *"congratulations :)"* ]]; then
  echo $TOX_OUTPUT
  echo "CLMC service unit tests failed."
  exit 1
fi
echo "----> Tox execution of unit tests passed successfully"

# install the service
echo "----> Installing CLMC web service"
pip3 install  .
if [ $? -ne 0 ] ; then
        echo "Failed: installing clmc-webservice"
		exit 1
fi

# create directory for CLMC service logs
echo "----> Creating CLMC web service log directory"
mkdir -p /var/log/flame/clmc

# Install minioclmc as systemctl service
# -----------------------------------------------------------------------
mkdir -p /opt/flame/clmc
start_script_file="/opt/flame/clmc/start.sh"
echo "#!/bin/bash" > $start_script_file
echo "export WORKON_HOME=${HOME}/.virtualenvs" >> $start_script_file
echo "source /usr/local/bin/virtualenvwrapper.sh" >> $start_script_file
echo "workon CLMC" >> $start_script_file
echo "pserve ${REPO_ROOT}/src/service/production.ini &" >> $start_script_file

chmod 755 $start_script_file

file="/lib/systemd/system/flameclmc.service"
echo "[Unit]" > $file
echo "Description=flameclmc" >> $file
echo "After=network.target" >> $file
echo "" >> $file
echo "[Service]" >> $file
echo "Type=forking" >> $file
echo "ExecStart=${start_script_file}" >> $file
echo "" >> $file
echo "[Install]" >> $file
echo "WantedBy=multi-user.target" >> $file

systemctl daemon-reload
systemctl enable flameclmc.service
systemctl start flameclmc.service

# wait for the clmc service to start
while ! nc -z localhost 9080
do
  echo "Waiting for clmc service port 9080 to be ready on localhost..."
  sleep 5
done

# configure the CLMC service
JSON="{\"aggregator_report_period\": ${REPORT_PERIOD}, \"aggregator_database_name\": \"${DATABASE_NAME}\", \"aggregator_database_url\": \"${INFLUX_URL}\"}"
echo "CONFIG JSON=${JSON}"
curl -H 'Content-Type: application/json' -X PUT -d "${JSON}" http://localhost:9080/aggregator/config

# start the aggregator
JSON="{\"action\": \"start\"}"
echo "START ACTION JSON=${JSON}"
curl -H 'Content-Type: application/json' -X PUT -d "${JSON}" http://localhost:9080/aggregator/control